Appellate Division, Second Department, Decisions

Home > Decisions
Home Decisions Advanced Search Style Manual Research Citation Services

Archives

July, 2015
Cases Decided July 29, 2015
Title | Judge | Docket No. | Slip Opinion No.
Andrew v Kerendian |  | 2014-01219 | 2015 NY Slip Op 06302
Aurora Loan Servs., LLC v Lopa |  | 2013-10154 | 2015 NY Slip Op 06303
Board of Educ. of Northport-E. Northport Union Free Sch. Dist. v Long Is. Power Auth. |  | 2013-06812 | 2015 NY Slip Op 06304
Brea v Salvatore |  | 2014-11964 | 2015 NY Slip Op 06305
Castiglione v Kruse |  | 2014-10307 | 2015 NY Slip Op 06306
Clark v City of New York |  | 2013-08016 | 2015 NY Slip Op 06307
Covert v Wisla Corp. |  | 2014-00478 | 2015 NY Slip Op 06308
Crawford v Smith |  | 2013-09969 | 2015 NY Slip Op 06309
Crown Constr. Bldrs. & Project Mgrs. Corp. v Chavez |  | 2013-09000 | 2015 NY Slip Op 06310
Earle v Village of Lindenhurst |  | 2014-11196 | 2015 NY Slip Op 06311
Feng Wang v A & W Travel, Inc. |  | 2013-07412 | 2015 NY Slip Op 06312
Greenpoint Sav. Bank v Avila |  | 2013-08915 | 2015 NY Slip Op 06313
Hartman v Milbel Enters., Inc. |  | 2013-05130 | 2015 NY Slip Op 06314
HSBC Bank USA, N.A. v Roumiantseva |  | 2013-09197 | 2015 NY Slip Op 06315
Kohulka v City of New York |  | 2014-07308 | 2015 NY Slip Op 06316
Mawere v Landau |  | 2013-09198 | 2015 NY Slip Op 06317
Moskovitz v City of New York |  | 2013-02661 | 2015 NY Slip Op 06318
Mudgil v Metropolitan Suburban Bus Auth. |  | 2014-03634 | 2015 NY Slip Op 06319
NYCTL 1998-2 Trust v Avila |  | 2013-08916 | 2015 NY Slip Op 06320
Onewest Bank, FSB v Colace |  | 2013-03487 | 2015 NY Slip Op 06321
People v Arocho |  | 2011-11338 | 2015 NY Slip Op 06322
People v Velazquez |  | 2013-06694 | 2015 NY Slip Op 06323
Rodriguez v City of New York |  | 2014-01104 | 2015 NY Slip Op 06324
Ruiz v Mortgage Elec. Registration Sys., Inc. |  | 2013-06572 | 2015 NY Slip Op 06325
Rumford v Singh |  | 2013-05537 | 2015 NY Slip Op 06326
S. Nicolia & Sons Realty Corp. v A.J.A. Concrete Ready Mix, Inc. |  | 2013-08447 | 2015 NY Slip Op 06327
School Aid Specialists, LLC v Board of Educ. of Warwick Val. Cent. Sch. Dist. |  | 2013-11539 | 2015 NY Slip Op 06328
State Farm Mut. Auto. Ins. Co. v Anikeyeva |  | 2013-07838 | 2015 NY Slip Op 06329
Stathis v Estate of Karas |  | 2013-01705 | 2015 NY Slip Op 06330
Sweeny v Millbrook Cent. Sch. Dist. |  | 2013-01270 | 2015 NY Slip Op 06331
Town of Huntington v Long Is. Power Auth. |  | 2013-06863 | 2015 NY Slip Op 06332
Williams-Guillaume v Bank of Am., N.A. |  | 2014-04497 | 2015 NY Slip Op 06333
Woodstock Constr. Group, Ltd. v State of New York |  | 2014-11180 | 2015 NY Slip Op 06334
Matter of AJM Capital II, LLC v Incorporated Vil. of Muttontown |  | 2013-09293 | 2015 NY Slip Op 06335
Matter of Allstate Ins. Co. v Carraro |  | 2014-02773 | 2015 NY Slip Op 06336
Matter of Alexandryia M.B. (Heather C.) |  | 2013-10084 | 2015 NY Slip Op 06337
Matter of Mercedes R.B. (Heather C.) |  | 2013-08606 | 2015 NY Slip Op 06338
Matter of Borrok v Town of Southampton |  | 2014-05755 | 2015 NY Slip Op 06339
Matter of Borrok v Town of Southampton |  | 2014-11038 | 2015 NY Slip Op 06340
Matter of Allison C. (Angel C.) |  | 2014-08628 | 2015 NY Slip Op 06341
Matter of Davis v Koch |  | 2014-07730 | 2015 NY Slip Op 06342
Matter of Fiduciary Ins. Co. v American Bankers Ins. Co. of Fla. | Hinds-radix | 2013-10862 | 2015 NY Slip Op 06343
Matter of Julia M.G. (Trinidad G.) |  | 2014-09021 | 2015 NY Slip Op 06344
Matter of C.H. v F.M. |  | 2013-11501 | 2015 NY Slip Op 06345
Matter of Herman v Herman |  | 2012-11008 | 2015 NY Slip Op 06346
Matter of Thomas J. |  | 2013-06077 | 2015 NY Slip Op 06347
Matter of James v Donovan |  | 2015-02774 | 2015 NY Slip Op 06348
Matter of Oshikanlu | Per Curiam. | 2012-05173 | 2015 NY Slip Op 06349
Matter of Quirolo v Israel |  | 2015-01204 | 2015 NY Slip Op 06350
Matter of Edward S. (Georgis-Corey) |  | 2014-10265 | 2015 NY Slip Op 06351
Matter of State of New York v Ted B. | Chambers | 2012-10730 | 2015 NY Slip Op 06352
Matter of Velasquez v New York State Div. of Hous. & Community Renewal |  | 2014-04709 | 2015 NY Slip Op 06353
People v Alvarez |  | 2012-04508 | 2015 NY Slip Op 06354
People v Anderson |  | 2012-01294 | 2015 NY Slip Op 06355
People v Boney |  | 2012-10302 | 2015 NY Slip Op 06356
People v Borges |  | 2012-07087 | 2015 NY Slip Op 06357
People v Canales |  | 2011-04782 | 2015 NY Slip Op 06358
People v Carter |  | 2013-08766 | 2015 NY Slip Op 06359
People v Council |  | 2013-03841 | 2015 NY Slip Op 06360
People v Crowl |  | 2013-11394 | 2015 NY Slip Op 06361
People v Dorvilier |  | 2012-09701 | 2015 NY Slip Op 06362
People v Dunston |  | 2011-01599 | 2015 NY Slip Op 06363
People v Ewart |  | 2013-09166 | 2015 NY Slip Op 06364
People v Feeney |  | 2010-03667 | 2015 NY Slip Op 06365
People v Fletcher |  | 2012-08855 | 2015 NY Slip Op 06366
People v Goode |  | 2013-04402 | 2015 NY Slip Op 06367
People v Huggins |  | 2012-08258 | 2015 NY Slip Op 06368
People v Hunter |  | 2013-02037 | 2015 NY Slip Op 06369
People v Johnakin |  | 2013-09078 | 2015 NY Slip Op 06370
People v Maldonado |  | 2011-07934 | 2015 NY Slip Op 06371
People v Noezile |  | 2000-00287 | 2015 NY Slip Op 06372
People v Palencia |  | 2013-08636 | 2015 NY Slip Op 06373
People v Raysor |  | 2011-01542 | 2015 NY Slip Op 06374
People v Isaiah S. |  | 2013-09077 | 2015 NY Slip Op 06375
People v Torres |  | 2013-05907 | 2015 NY Slip Op 06376
People v Wellington |  | 2009-00585 | 2015 NY Slip Op 06377
Cases Decided July 22, 2015
Title | Judge | Docket No. | Slip Opinion No.
Matter of Brown v Brown |  | 2014-07464 | 2015 NY Slip Op 06240
Matter of Hayden C. (Tafari C.) |  | 2014-08407 | 2015 NY Slip Op 06241
Matter of Cambre v Kirton |  | 2014-09177 | 2015 NY Slip Op 06242
Matter of Cronin | Per Curiam. | 2012-06884 | 2015 NY Slip Op 06243
Matter of Ostojic v Gee |  | 2013-08802 | 2015 NY Slip Op 06244
Matter of Premier Capital, LLC v Schnitzler |  | 2014-05085 | 2015 NY Slip Op 06245
Matter of Rappaport v Village of Saltaire |  | 2013-05148 | 2015 NY Slip Op 06246
Matter of Rivera |  | 2014-05743 | 2015 NY Slip Op 06247
Matter of Schwartz | Per Curiam. | 2014-06175 | 2015 NY Slip Op 06248
Matter of Villalobos v New York City Fire Dept. |  | 2013-08145 | 2015 NY Slip Op 06249
People v Bethune |  | 2009-06026 | 2015 NY Slip Op 06250
People v Bruce |  | 2012-07220 | 2015 NY Slip Op 06251
People v Cesar | Dillon, J.P. | 2013-02141 | 2015 NY Slip Op 06252
People v Fabregas |  | 2011-07614 | 2015 NY Slip Op 06253
People v Fulford |  | 1999-05260 | 2015 NY Slip Op 06254
People v Hendricks |  | 2014-01991 | 2015 NY Slip Op 06255
People v Holloway |  | 2012-02411 | 2015 NY Slip Op 06256
People v Knotts |  | 2013-10772 | 2015 NY Slip Op 06257
People v Lawson |  | 2006-00233 | 2015 NY Slip Op 06258
People v Lundi |  | 2011-10025 | 2015 NY Slip Op 06259
People v Marsden |  | 2008-07743 | 2015 NY Slip Op 06260
People v Soler |  | 2012-07926 | 2015 NY Slip Op 06261
People v Taylor |  | 2012-00775 | 2015 NY Slip Op 06262
People v Williams |  | 2013-09662 | 2015 NY Slip Op 06263
People ex rel. Udell v Queens County Dist. Attorney |  | 2015-05551 | 2015 NY Slip Op 06264
Cases Decided July 22, 2015
Title | Judge | Docket No. | Slip Opinion No.
Bayview Loan Servicing, LLC v Bernard |  | 2015-00338 | 2015 NY Slip Op 06202
Brandeis School, Inc. v Yakobowicz |  | 2013-10279 | 2015 NY Slip Op 06203
Brown v Roosevelt Union Free School Dist. |  | 2015-01496 | 2015 NY Slip Op 06204
Campisi v Gambar Food Corp. |  | 2013-08177 | 2015 NY Slip Op 06205
Caterpillar Ins. Co. v Metro Constr. Equities |  | 2013-08108 | 2015 NY Slip Op 06206
Chudinova v Kleyner |  | 2014-01330 | 2015 NY Slip Op 06207
Citibank, N.A. v Cabrera |  | 2014-10003 | 2015 NY Slip Op 06208
Combs v City of New York |  | 2013-05957 | 2015 NY Slip Op 06209
Darby Group Cos., Inc. v Wulforst Acquisition, LLC |  | 2013-10128 | 2015 NY Slip Op 06210
Peretz v Village of Great Neck Plaza |  | 2014-07623 | 2015 NY Slip Op 06211
Finn v Zinn |  | 2013-08632 | 2015 NY Slip Op 06212
Garcia v Government Employees Ins. Co. |  | 2013-10278 | 2015 NY Slip Op 06213
Haines v Verazzano of Dutchess, LLC |  | 2014-06740 | 2015 NY Slip Op 06214
Hedley's, Inc. v Airwaves Global Logistics, LLC |  | 2014-01163 | 2015 NY Slip Op 06215
Hinck v Hinck |  | 2013-08826 | 2015 NY Slip Op 06216
JP Morgan Chase Bank v Schott |  | 2013-00592ON MOTION | 2015 NY Slip Op 06217
Kanic Realty Assoc., Inc. v Suffolk County Water Auth. |  | 2013-10996 | 2015 NY Slip Op 06218
Kung v Scottsdale Ins. Co. |  | 2013-11538 | 2015 NY Slip Op 06219
Lopez v Cobra Logistics, Inc. |  | 2014-01057 | 2015 NY Slip Op 06220
Manufacturers & Traders Trust Co. v Berthole |  | 2013-10144 | 2015 NY Slip Op 06221
Marrero v Sosinsky |  | 2014-00482 | 2015 NY Slip Op 06222
Matos v Shelter Rock Homes, Inc. |  | 2013-08997 | 2015 NY Slip Op 06223
Monzon v Brown |  | 2014-06872 | 2015 NY Slip Op 06224
North Oyster Bay Baymen's Assn. v Town of Oyster Bay |  | 2014-01227 | 2015 NY Slip Op 06225
Nugent v Hubbard |  | 2014-03818 | 2015 NY Slip Op 06226
Payano v Patel |  | 2013-09388 | 2015 NY Slip Op 06227
People v Rodriguez |  | 2012-09312 | 2015 NY Slip Op 06228
Phoenix Asset Mgt., LLC v X & Y Group Dev., LLC |  | 2014-01169 | 2015 NY Slip Op 06229
Scott v Ward |  | 2014-09265 | 2015 NY Slip Op 06230
Sholom & Zuckerbrot Realty, LLC v Gallant |  | 2013-07575 | 2015 NY Slip Op 06231
Silver v Sportsstuff, Inc. |  | 2013-07573 | 2015 NY Slip Op 06232
Silver v Sportsstuff, Inc. |  | 2013-08934 | 2015 NY Slip Op 06233
Stein v Chiera |  | 2013-11445 | 2015 NY Slip Op 06234
Tanaysha T. v City of New York |  | 2013-01971 | 2015 NY Slip Op 06235
Tirpack v 125 N. 10, LLC |  | 2013-04511 | 2015 NY Slip Op 06236
U.S. Bank Natl. Assn. v Ventura |  | 2014-00141 | 2015 NY Slip Op 06237
E. V. v R. V. |  | 2014-06687 | 2015 NY Slip Op 06238
Zwarycz v Marnia Constr., Inc. |  | 2014-09379 | 2015 NY Slip Op 06239

Cases Decided July 15, 2015
Title | Judge | Docket No. | Slip Opinion No.
Amandola v Roman Catholic Diocese of Rockville Ctr. |  | 2013-07937 | 2015 NY Slip Op 06099
Aurora Loan Servs., LLC v Hiyo |  | 2014-08425 | 2015 NY Slip Op 06100
Avenue C Med., P.C. v Encompass Ins. of MA |  | 2014-00659 | 2015 NY Slip Op 06101
Barone v Barone |  | 2013-03681 | 2015 NY Slip Op 06102
Bergin v Golshani |  | 2013-08946 | 2015 NY Slip Op 06103
Brits v Flores |  | 2014-07898 | 2015 NY Slip Op 06104
Congregation Beth Shalom of Kingsbay v Yaakov |  | 2014-00578 | 2015 NY Slip Op 06105
Copacabana Realty, LLC v Fireman's Fund Ins. Co. |  | 2013-08910 | 2015 NY Slip Op 06106
David v Byron |  | 2014-03824 | 2015 NY Slip Op 06107
DKR Mtge. Asset Trust 1 v Rivera |  | 2014-07186 | 2015 NY Slip Op 06108
Doria v Benisch |  | 2014-01566 | 2015 NY Slip Op 06109
Gerald Gardner Wright, P.C. & Assoc. v Champion Prop. Mgt., LLC |  | 2013-10389 | 2015 NY Slip Op 06110
Graham v Kone, Inc. |  | 2014-07513 | 2015 NY Slip Op 06111
Griffin v Sherwood Vil., Co-op "C", Inc. |  | 2013-07707 | 2015 NY Slip Op 06112
Haber v Raso |  | 2014-05061 | 2015 NY Slip Op 06113
HSBC Bank USA, N.A. v Wright |  | 2014-07581 | 2015 NY Slip Op 06114
HSBC Bank, USA v Despot |  | 2014-10174 | 2015 NY Slip Op 06115
Imperatore v 329 Menahan St., LLC |  | 2014-11968 | 2015 NY Slip Op 06116
Krigsman v Cyngiel |  | 2014-03443 | 2015 NY Slip Op 06117
Loancare v Firshing |  | 2014-07529 | 2015 NY Slip Op 06118
Mazur Bros. Realty, LLC v State of New York |  | 2014-01090 | 2015 NY Slip Op 06119
Meredith v Siben & Siben, LLP |  | 2013-11282 | 2015 NY Slip Op 06120
Morales v City of New York |  | 2013-06490 | 2015 NY Slip Op 06121
Nationwide Gen. Ins. Co. v Linwood Bates III |  | 2014-01986 | 2015 NY Slip Op 06122
Oseff v Scotti |  | 2013-10870 | 2015 NY Slip Op 06123
Quartarolo-Johanson v Johanson |  | 2013-07940 | 2015 NY Slip Op 06124
Ricketts v New York Cong. Nursing Ctr., Inc. |  | 2014-05332 | 2015 NY Slip Op 06125
Rivera v Department of Hous. Preserv. & Dev. of City of New York |  | 2014-01607 | 2015 NY Slip Op 06126
Rosenblum v Island Custom Stairs, Inc. |  | 2014-01048 | 2015 NY Slip Op 06127
Stewart v Dubuisson |  | 2014-04059 | 2015 NY Slip Op 06128
Walker v Walker |  | 2013-01178 | 2015 NY Slip Op 06129
Wan Li Situ v MTA Bus Co. |  | 2014-09993 | 2015 NY Slip Op 06130
Yen-Fu Chen v Oheka Catering, LLC |  | 2014-09250 | 2015 NY Slip Op 06131
Yung Chong Ho v Uppal |  | 2014-11506 | 2015 NY Slip Op 06132
Renhe Zhang v Gerald W. Purcell Assoc., Ltd. |  | 2013-06028 | 2015 NY Slip Op 06133
Matter of Makhi A. (Jamillah A.) |  | 2014-08331 | 2015 NY Slip Op 06134
Matter of Allstate Ins. Co. v Laldharry |  | 2014-06493 | 2015 NY Slip Op 06135
Matter of Arzadi |  | 2014-00700 ON MOTION | 2015 NY Slip Op 06136
Matter of Ethan B. (Frederick B.) |  | 2014-04907 | 2015 NY Slip Op 06137
Matter of Barrett v Village of Wappingers Falls |  | 2014-11489 | 2015 NY Slip Op 06138
Matter of Best v Schwartz |  | 2015-01499, | 2015 NY Slip Op 06139
Matter of Bhargava v City of New York |  | 2014-05762 | 2015 NY Slip Op 06140
Matter of Dylan C. (Carmen V.) |  | 2013-11517 | 2015 NY Slip Op 06141
Matter of Cascardo |  | 2013-07523 | 2015 NY Slip Op 06142
Matter of County of Orange v Monroe Bakertown Rd. Realty, Inc. |  | 2013-04685 | 2015 NY Slip Op 06143
Matter of Culberson v Fisher |  | 2014-06799 | 2015 NY Slip Op 06144
Matter of Cyngiel |  | 2014-00180 | 2015 NY Slip Op 06145
Matter of Kogan | Per Curiam. | 2014-00131 | 2015 NY Slip Op 06146
Matter of Levitis | Per Curiam. | 2015-00926 | 2015 NY Slip Op 06147
Matter of Livoti | Per Curiam. | 2015-00735 | 2015 NY Slip Op 06148
Matter of Mazur Bros. Realty, LLC v State of New York |  | 2014-02719 | 2015 NY Slip Op 06149
Matter of Nixon v Christian |  | 2014-07732 | 2015 NY Slip Op 06150
Matter of Tiyana D.R. |  | 2014-06751 | 2015 NY Slip Op 06151
Matter of Ramos | Per Curiam. | 2012-10976 | 2015 NY Slip Op 06152
Matter of Helen S. (Falero) |  | 2014-10130 | 2015 NY Slip Op 06153
Matter of Schneider | Per Curiam. | 2013-08543 | 2015 NY Slip Op 06154
Matter of Sims v Boykin |  | 2014-11258 | 2015 NY Slip Op 06155
Matter of Tolkinen v Siewert |  | 2014-01929 | 2015 NY Slip Op 06156
Matter of Alexa V. (Antonio V.) |  | 2013-09106 | 2015 NY Slip Op 06157
Matter of Velardi | Per Curiam. | 2013-07945 | 2015 NY Slip Op 06158
Matter of Jeremiah W. (Ronald W.) |  | 2014-03871 | 2015 NY Slip Op 06159
People v Barnhill |  | 2013-04911 | 2015 NY Slip Op 06160
People v Bushuyeva |  | 2012-09658 | 2015 NY Slip Op 06161
People v Chance |  | 2010-04664 | 2015 NY Slip Op 06162
People v Davidson |  | 2013-09529 | 2015 NY Slip Op 06163
People v DiSalvo |  | 2013-07651 | 2015 NY Slip Op 06164
People v Duren |  | 2013-00985 | 2015 NY Slip Op 06165
People v Georges |  | 2013-09676 | 2015 NY Slip Op 06166
People v Irving |  | 2012-10322 | 2015 NY Slip Op 06167
People v LaTouche |  | 2006-01150 | 2015 NY Slip Op 06168
People v McKane |  | 2014-01985 The People of the State of New York, respondent, v Calvin | 2015 NY Slip Op 06169
People v Reyes |  | 2010-06674 | 2015 NY Slip Op 06170
People v Riley |  | 2004-03714 | 2015 NY Slip Op 06171
People v Robinson |  | 2014-01446 | 2015 NY Slip Op 06172
People v Swenson |  | 2010-09511ON MOTION | 2015 NY Slip Op 06173

Cases Decided July 8, 2015
Title | Judge | Docket No. | Slip Opinion No.
Alotta v Diaz |  | 2014-06581 | 2015 NY Slip Op 05899
Bowman v Bowman |  | 2014-05422 | 2015 NY Slip Op 05900
Cabrera v Magussen |  | 2014-05027 | 2015 NY Slip Op 05901
Caldara v Utica Mut. Ins. Co. |  | 2013-11164 | 2015 NY Slip Op 05902
Chavez v Delta Intl. Mach. Corp. |  | 2014-05236 | 2015 NY Slip Op 05903
Comprehensive Mental Assessment & Med. Care, P.C. v Gusrae Kaplan Nusbaum, PLLC |  | 2013-10499 | 2015 NY Slip Op 05904
Cuttler v Cuttler |  | 2014-01350 | 2015 NY Slip Op 05905
Cuttler v Cuttler |  | 2014-10860 | 2015 NY Slip Op 05906
Deutsche Bank Natl. Trust Co. v Gavrielova |  | 2013-07577 | 2015 NY Slip Op 05907
5000, Inc. v Hudson One, Inc. |  | 2012-07355 | 2015 NY Slip Op 05908
5000, Inc. v Hudson One, Inc. |  | 2014-01696 | 2015 NY Slip Op 05909
Foley Inc. v Metropolis Superstructures, Inc. |  | 2013-01622 | 2015 NY Slip Op 05910
Hernandez v Alstom Transp., Inc. |  | 2013-03915 | 2015 NY Slip Op 05911
HSBC Bank, USA v Hagerman |  | 2014-01949 | 2015 NY Slip Op 05912
Island Assoc. Real Estate, Inc. v Doukas |  | 2012-06200 | 2015 NY Slip Op 05913
Jones v City of New York |  | 2014-05219 | 2015 NY Slip Op 05914
Kraus v Kraus | Dillon, J.P. | 2013-04824 | 2015 NY Slip Op 05915
Lajqi v Lajqi |  | 2014-07910 | 2015 NY Slip Op 05916
Lanza v Carbone |  | 2013-10557 | 2015 NY Slip Op 05917
Mahabir v Suffolk County Water Auth. |  | 2013-07139 | 2015 NY Slip Op 05918
Montenegro v P12, LLC |  | 2014-08939 | 2015 NY Slip Op 05919
Nura v International Shoppes, LLC |  | 2014-04870 | 2015 NY Slip Op 05920
O'Connor v Metro Mgt. Dev., Inc. |  | 2014-00694 | 2015 NY Slip Op 05921
Onewest Bank, FSB v Prince |  | 2013-09359 | 2015 NY Slip Op 05922
Oriental v U-Haul Co. of Ariz. |  | 2014-08456 | 2015 NY Slip Op 05923
PHH Mtge. Corp. v Celestin |  | 2014-04882 | 2015 NY Slip Op 05924
Piccoli v Panos |  | 2013-01542 | 2015 NY Slip Op 05925
Politopoulos v City of New York |  | 2013-07855 | 2015 NY Slip Op 05926
Pyronneau v Pyronneau |  | 2014-04051 | 2015 NY Slip Op 05927
Rosa v Mendon Leasing Corp. |  | 2014-03338 | 2015 NY Slip Op 05928
Spencer v Tower Ins. Group Corp. |  | 2014-04708 | 2015 NY Slip Op 05929
Stein v Bauer |  | 2014-01997 | 2015 NY Slip Op 05930
Taylor v New York City Tr. Auth. |  | 2012-03465 | 2015 NY Slip Op 05931
Tracy v Vassar Bros. Hosp. |  | 2013-01541 | 2015 NY Slip Op 05932
U.S. Bank N.A. v Alba |  | 2013-08737 | 2015 NY Slip Op 05933
Vanderhurst v Nobile |  | 2014-06105 | 2015 NY Slip Op 05934
Wells Fargo Bank v Allen |  | 2013-10841 | 2015 NY Slip Op 05935
Matter of Alleyne v Ally |  | 2014-11715 | 2015 NY Slip Op 05936
Matter of Nyomi B. (Nefreida W.) |  | 2013-11345 | 2015 NY Slip Op 05937
Matter of Sha-Naya M.S.C. (Derrick C.) |  | 2014-07008 | 2015 NY Slip Op 05938
Matter of Covington v Ray |  | 2014-06479 | 2015 NY Slip Op 05939
Matter of Curtis |  | 2013-10323 | 2015 NY Slip Op 05940
Matter of Denkewitz v Sundara |  | 2014-04452 | 2015 NY Slip Op 05941
Matter of Kayla F. (Kevin F.) |  | 2013-10881 | 2015 NY Slip Op 05942
Matter of Glass v County of Suffolk |  | 2014-00224 | 2015 NY Slip Op 05943
Matter of Goldfarb v Szabo |  | 2014-04357 | 2015 NY Slip Op 05944
Matter of Hyde Park Landing, Ltd. v Town of Hyde Park |  | 2013-11209 | 2015 NY Slip Op 05945
Matter of Kadyorios v Kirton |  | 2014-06392 | 2015 NY Slip Op 05946
Matter of Haide L.G.M. v Santo D.S.M. |  | 2014-10541 | 2015 NY Slip Op 05947
Matter of Nelson v McGriff |  | 2014-08731 | 2015 NY Slip Op 05948
Matter of Oakley v Cond-Arnold |  | 2014-06972 | 2015 NY Slip Op 05949
Matter of David P. (Elisa P.) |  | 2013-08609 | 2015 NY Slip Op 05950
Matter of Patrick v Zoning Bd. of Appeals of Vil. of Russell Gardens |  | 2013-10536 | 2015 NY Slip Op 05951
Matter of Gabriel W. (Steven C.) |  | 2014-01602 | 2015 NY Slip Op 05952
Matter of Westchester County Dept. of Social Servs. v Arnoldo B. |  | 2014-05839 | 2015 NY Slip Op 05953
People v Badia |  | 2012-04523 | 2015 NY Slip Op 05954
People v Barksdale |  | 2012-01422 | 2015 NY Slip Op 05955
People v Burno |  | 2013-09310 | 2015 NY Slip Op 05956
People v Clarke |  | 2008-00671 | 2015 NY Slip Op 05957
People v Collezo |  | 2011-10064 | 2015 NY Slip Op 05958
People v Dawson |  | 2012-04044 | 2015 NY Slip Op 05959
People v Dupree |  | 2013-07337 | 2015 NY Slip Op 05960
People v Hall |  | 2013-00806 | 2015 NY Slip Op 05961
People v Hall |  | 2015-04635 | 2015 NY Slip Op 05962
People v Hardy |  | 2012-09914 | 2015 NY Slip Op 05963
People v Heron |  | 2013-05469 | 2015 NY Slip Op 05964
People v LaRosa |  | 2012-08360 | 2015 NY Slip Op 05965
People v Priester |  | 2013-06914 | 2015 NY Slip Op 05966
People v Rosas |  | 2013-05033 | 2015 NY Slip Op 05967
People v Samuels |  | 2013-01739 | 2015 NY Slip Op 05968
People v Ullah |  | 2012-11057 | 2015 NY Slip Op 05969
People v Vaughn |  | 2013-10347 | 2015 NY Slip Op 05970

Cases Decided July 1, 2015
Title | Judge | Docket No. | Slip Opinion No.
Bank of N.Y. v Stein |  | 2014-05779 | 2015 NY Slip Op 05628
Boudine v Goldmaker, Inc. |  | 2014-08480 | 2015 NY Slip Op 05629
Brothers v Bartling |  | 2014-07559 | 2015 NY Slip Op 05630
Camac v 550 Realty Hgts., LLC |  | 2014-06271 | 2015 NY Slip Op 05631
Citimortgage, Inc. v Kowalski |  | 2014-03941 | 2015 NY Slip Op 05632
Cremosa Food Co., LLC v Amella |  | 2014-07220 | 2015 NY Slip Op 05633
Deutsche Bank Trust Co. Ams. v Vitellas | Cohen, J. | 2013-07197 | 2015 NY Slip Op 05634
Diaz v Diaz |  | 2014-04150 | 2015 NY Slip Op 05635
Estrada v Selman |  | 2014-03733 | 2015 NY Slip Op 05636
Excess Line Assn. of N.Y. (ELANY) v Waldorf & Assoc. |  | 2013-06615 | 2015 NY Slip Op 05637
Fernandez v State of New York |  | 2014-00515 | 2015 NY Slip Op 05638
Forlenza v Miglio |  | 2014-07836 | 2015 NY Slip Op 05639
GFRE, Inc. v U.S. Bank, N.A. |  | 2014-01120 | 2015 NY Slip Op 05640
Hallwood v Incorporated Vil. of Old Westbury |  | 2014-07543 | 2015 NY Slip Op 05641
Hecker v Liebgold |  | 2014-05143 | 2015 NY Slip Op 05642
Imperium Ins. Co. v Utica First Ins. Co. |  | 2014-02658 | 2015 NY Slip Op 05643
Istomin v Istomin |  | 2013-09320 | 2015 NY Slip Op 05644
Kaplan v Kaplan |  | 2014-00906 | 2015 NY Slip Op 05645
Knapp v Town of Hempstead |  | 2014-10531 | 2015 NY Slip Op 05646
Lamparillo v Lamparillo |  | 2012-06232ON MOTION | 2015 NY Slip Op 05647
Loccisano v Ayers |  | 2013-10305 | 2015 NY Slip Op 05648
Manganiello v Ahmed |  | 2012-08804 | 2015 NY Slip Op 05649
Nasca v Sgro |  | 2013-04626 | 2015 NY Slip Op 05650
1136 Realty, LLC v 213 Union St. Realty Corp. |  | 2013-06818 | 2015 NY Slip Op 05651
Ortiz v AGL Trucking Corp. |  | 2015-01530 | 2015 NY Slip Op 05652
Osarczuk v Associated Univs., Inc. |  | 2013-07904 | 2015 NY Slip Op 05653
Ostrovsky v Stern |  | 2014-04698 | 2015 NY Slip Op 05654
O'Toole v Vollmer |  | 2014-07210 | 2015 NY Slip Op 05655
People v Davis |  | 2011-04636 | 2015 NY Slip Op 05656
People v Dyson |  | 2014-10682 | 2015 NY Slip Op 05657
People v Jones |  | 2014-00566 | 2015 NY Slip Op 05658
Pietrafesa v Canestro |  | 2015-00800 | 2015 NY Slip Op 05659
Shannon v Shannon |  | 2014-09961 | 2015 NY Slip Op 05660
Stein v Stein |  | 2014-02529 | 2015 NY Slip Op 05661
TKM Group, Inc. v Indian Harbor Ins. Co. |  | 2013-09319 | 2015 NY Slip Op 05662
Town of Hempstead v AJM Capital II, LLC |  | 2013-08176 | 2015 NY Slip Op 05663
Turner v Turner |  | 2014-01194 | 2015 NY Slip Op 05664
Vitiello v Merwin |  | 2013-05694 | 2015 NY Slip Op 05665
Vitolo v Suarez |  | 2014-08925 | 2015 NY Slip Op 05666
Walker v Schuster |  | 2014-09252 | 2015 NY Slip Op 05667
Watt v County of Nassau |  | 2014-05374 | 2015 NY Slip Op 05668
Weldon v Vepp Realty, LLC |  | 2014-07740 | 2015 NY Slip Op 05669
Yehia v Marphil Realty Corp. |  | 2013-07705 | 2015 NY Slip Op 05670
Matter of Arkali v Muuss |  | 2014-03091 | 2015 NY Slip Op 05671
Matter of Arkali v Suffolk County Dept. of Social Servs. |  | 2014-04652 | 2015 NY Slip Op 05672
Matter of Michael B. (Samantha B.) |  | 2014-03811 | 2015 NY Slip Op 05673
Matter of Castelli | Per Curiam. | 2014-00322 | 2015 NY Slip Op 05674
Matter of Fisher | Per Curiam. | 2015-01899 | 2015 NY Slip Op 05675
Matter of Matthew G. (Miguel G.) |  | 2013-09936 | 2015 NY Slip Op 05676
Matter of Halloran | Per Curiam. | 2015-00352 | 2015 NY Slip Op 05677
Matter of Heavy Constr. Co., Inc. v Metro Constr. Equities, Inc. |  | 2013-04192 | 2015 NY Slip Op 05678
Matter of Raven K. (Adam C.) |  | 2014-06457 | 2015 NY Slip Op 05679
Matter of Lao v Gonzales |  | 2014-10752 | 2015 NY Slip Op 05680
Matter of Masciello v Masciello |  | 2014-05369 | 2015 NY Slip Op 05681
Matter of Middleton v Stringham |  | 2014-10821 | 2015 NY Slip Op 05682
Matter of Dillon R. |  | 2014-07575 | 2015 NY Slip Op 05683
Matter of Rosenfeld | Per Curiam. | 2015-02209 | 2015 NY Slip Op 05684
Matter of Richard S. (Lacey P.) |  | 2014-00445 | 2015 NY Slip Op 05685
Matter of Sarabia v Sarabia |  | 2014-06390 | 2015 NY Slip Op 05686
Matter of Sosa v Serrano |  | 2015-00185 | 2015 NY Slip Op 05687
Matter of Teixeira v Spota |  | 2015-02612 | 2015 NY Slip Op 05688
Matter of Weber | Per Curiam. | 2013-04637 | 2015 NY Slip Op 05689
Matter of Williamsburg & Greenpoint Parents: Our Pub. Schools! v Board of Trustees, State Univ. of N.Y. |  | 2013-04383 | 2015 NY Slip Op 05690
People v Buckery |  | 2014-02486 | 2015 NY Slip Op 05691
People v Colliton |  | 2014-02399 | 2015 NY Slip Op 05692
People v Fortier |  | 2014-07162 | 2015 NY Slip Op 05693
People v Garcia |  | 2014-09782 | 2015 NY Slip Op 05694
People v Garvin |  | 2012-09698 | 2015 NY Slip Op 05695
People v Gavarette |  | 2013-11069 ON MOTION | 2015 NY Slip Op 05696
People v Hamilton |  | 1995-06509 | 2015 NY Slip Op 05697
People v Hatcher |  | 2011-11928 | 2015 NY Slip Op 05698
People v Jean |  | 2014-01409 | 2015 NY Slip Op 05699
People v Mack |  | 2013-10183 | 2015 NY Slip Op 05700
People v McAllister |  | 2013-04102 | 2015 NY Slip Op 05701
People v McMillan |  | 2011-00263 | 2015 NY Slip Op 05702
People v Rivera |  | 2011-07822 | 2015 NY Slip Op 05703
People v Rucano |  | 2011-01960 | 2015 NY Slip Op 05704
People v Spitzer |  | 2012-05370 | 2015 NY Slip Op 05705
People v Syville |  | 2012-01830 | 2015 NY Slip Op 05706
People v Wiggs |  | 2013-08055 | 2015 NY Slip Op 05707

Home | Contents | Site Search | Publications | Decisions | Decision Search
Citation Services | Archives | Style Manual | Legal Research Portal
New York State Law Reporting Bureau
17 Lodge Street, Albany, NY 12207
phone: (518) 453-6900
fax: (518) 426-1640